import json
from collections import defaultdict


def find_duplicate_ids(jsonl_file):
    # 用于记录每个 id 出现的行号
    id_to_lines = defaultdict(list)

    with open(jsonl_file, "r", encoding="utf-8") as f:
        for line_num, line in enumerate(f, 1):
            try:
                data = json.loads(line.strip())
                if "id" in data:
                    id_value = data["id"]
                    id_to_lines[id_value].append(line_num)
            except json.JSONDecodeError:
                print(f"警告：第 {line_num} 行不是有效的 JSON，已跳过。")

    # 筛选出重复的 id
    duplicates = {
        id_val: lines for id_val, lines in id_to_lines.items() if len(lines) > 1
    }

    return duplicates


def parse_args():
    import argparse

    parser = argparse.ArgumentParser(description="检查JSONL文件中的重复ID")
    parser.add_argument("jsonl_file", help="要检查的JSONL文件路径")
    return parser.parse_args()


def main():
    args = parse_args()
    duplicates = find_duplicate_ids(args.jsonl_file)

    if duplicates:
        print("发现重复的 id：")
        for id_val, lines in duplicates.items():
            print(f"id '{id_val}' 在以下行重复出现: {lines}")
    else:
        print("未发现重复的 id。")


if __name__ == "__main__":
    main()



import json


def safety_json_loader(json_str, index=None):
    try:
        return json.loads(json_str)
    except json.JSONDecodeError:
        # 处理错误的JSON字符串
        # 可以选择忽略错误的行或进行其他处理
        print(
            f"{'' if index is None else f'Line {index} '}Error decoding JSON: {json_str}"
        )
        return None
    # print("yes"


def load_json(json_path, process_func=lambda x: x):
    # print("yes")
    with open(json_path, "r") as f:
        result = []
        for index, line in enumerate(f):
            stripped = line.strip()
            if stripped:  # 检查是否非空
                loaded = safety_json_loader(stripped, index)
                if loaded is not None:  # 检查是否非None
                    loaded = process_func(loaded)
                    result.append(loaded)
    return result


def save_normal_json(json_info, json_path):
    with open(json_path, "w") as f:
        for info in json_info:
            print(json.dumps(info, ensure_ascii=False), file=f)


def flatten_dict(my_dict):
    result_list = []
    for k, v in my_dict.items():
        if isinstance(v, dict):
            yield from flatten_dict(v)
        else:
            yield k, v



import re


def normalize_newlines(text):
    # 将不同平台的换行符统一为 \n
    text = re.sub(r"\r\n", "\n", text)
    # 将空白行替换为换行符
    text = re.sub(r"\n[ \t]*\n", "\n\n", text)
    # 将两个以上的换行符替换为两个换行符
    return re.sub(r"\n{3,}", "\n\n", text)


# 正则表达式保留指定标签，并记录删除的标签
def remove_unwanted_tags(html, allowed_tags=[]):
    # 匹配所有标签
    pattern = re.compile(r"<(/?)([^ >/]+)([^>]*)>")
    deleted_tags = set()  # 记录被删除的标签类型

    def replace_tag(match):
        tag_name = match.group(2)
        if tag_name in allowed_tags:
            return match.group(0)  # 保留匹配的标签
        else:
            deleted_tags.add(tag_name)  # 记录被删除的标签
            return ""  # 移除不匹配的标签

    # 替换 HTML 中的标签
    cleaned_html = pattern.sub(replace_tag, html)
    return cleaned_html, deleted_tags



import logging
import os


def get_logger(input_dir, log_name="app.log", mode="w", console=True, file=True):
    # 创建 Logger
    logger = logging.getLogger(__name__)
    logger.setLevel(logging.DEBUG)  # 设置日志级别

    # 创建控制台 Handler
    console_handler = logging.StreamHandler()
    console_handler.setLevel(logging.DEBUG)

    # 创建文件 Handler
    file_handler = logging.FileHandler(os.path.join(input_dir, log_name), mode=mode)
    file_handler.setLevel(logging.DEBUG)

    # 创建 Formatter
    formatter = logging.Formatter(
        "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
    )

    # 将 Formatter 添加到 Handler
    if console:
        console_handler.setFormatter(formatter)
        logger.addHandler(console_handler)
    if file:
        file_handler.setFormatter(formatter)
        logger.addHandler(file_handler)
    return logger
